RGBLedMatrixOptions

Struct RGBLedMatrixOptions 

#[repr(C)]
pub struct RGBLedMatrixOptions {
Show 19 fields pub hardware_mapping: *const c_char, pub rows: c_int, pub cols: c_int, pub chain_length: c_int, pub parallel: c_int, pub pwm_bits: c_int, pub pwm_lsb_nanoseconds: c_int, pub pwm_dither_bits: c_int, pub brightness: c_int, pub scan_mode: c_int, pub row_address_type: c_int, pub multiplexing: c_int, pub led_rgb_sequence: *const c_char, pub pixel_mapper_config: *const c_char, pub panel_type: *const c_char, pub disable_hardware_pulsing: c_char, pub show_refresh_rate: c_char, pub inverse_colors: c_char, pub limit_refresh_rate_hz: c_int,
}
Parameters to create a new matrix.

To get the defaults, non-set values have to be initialized to zero, so you should zero out this struct before setting anything.

Fields

hardware_mapping: *const c_charrows: c_intcols: c_intchain_length: c_intparallel: c_intpwm_bits: c_intpwm_lsb_nanoseconds: c_intpwm_dither_bits: c_intbrightness: c_intscan_mode: c_introw_address_type: c_intmultiplexing: c_intled_rgb_sequence: *const c_charpixel_mapper_config: *const c_charpanel_type: *const c_chardisable_hardware_pulsing: c_char

The following are boolean flags, all off by default

show_refresh_rate: c_charinverse_colors: c_charlimit_refresh_rate_hz: c_int

Implementations

Source

impl RGBLedMatrixOptions

pub fn new() -> Self

pub fn hardware_mapping(self, mapping: &str) -> Self

pub fn rows(self, rows: u16) -> Self

pub fn cols(self, cols: u16) -> Self

pub fn chain_length(self, length: u16) -> Self

pub fn parallel(self, parallel: u16) -> Self

pub fn pwm_bits(self, bits: u16) -> Self

pub fn pwm_lsb_nanoseconds(self, ns: u16) -> Self

pub fn pwm_dither_bits(self, bits: u16) -> Self

pub fn brightness(self, brightness: u16) -> Self

pub fn scan_mode(self, mode: u16) -> Self

pub fn row_address_type(self, address_type: u16) -> Self

pub fn multiplexing(self, multiplexing: u16) -> Self

pub fn disable_hardware_pulsing(self, disable: bool) -> Self

pub fn show_refresh_rate(self, show: bool) -> Self

pub fn inverse_colors(self, inverse: bool) -> Self

pub fn led_rgb_sequence(self, sequence: &str) -> Self

pub fn pixel_mapper_config(self, config: &str) -> Self

pub fn panel_type(self, panel_type: &str) -> Self

pub fn limit_refresh_rate_hz(self, hz: u32) -> Self

pub fn build(self) -> Box<RGBLedMatrix>

pub fn build_with_rt_options( self, rt_options: RGBLedRuntimeOptions, ) -> Box<RGBLedMatrix>