#[repr(C)]pub struct RGBLedRuntimeOptions {
pub gpio_slowdown: c_int,
pub daemon: c_int,
pub drop_privileges: c_int,
pub do_gpio_init: bool,
}Expand description
Runtime options to simplify doing common things for many programs such as dropping privileges and becoming a daemon.
Fields
gpio_slowdown: c_intdaemon: c_intdrop_privileges: c_intdo_gpio_init: boolImplementations
Sourceimpl RGBLedRuntimeOptions
impl RGBLedRuntimeOptions
pub fn new() -> Self
pub fn gpio_slowdown(self, slowdown: u32) -> Self
pub fn daemon(self, run_as_daemon: bool) -> Self
pub fn drop_priviliges(self, do_drop_privileges: bool) -> Self
pub fn do_gpio_init(self, do_gpio_init: bool) -> Self